@@ -11,6 +11,7 @@ class TestMattWilson(unittest.TestCase):
     def test_draw_ascii_spinner(self):
         wmw.draw_ascii_spinner(0.001)
 
+
 m, t = Mock(), Mock()
 
 @patch('subprocess.call', m)
@@ -25,4 +26,18 @@ def test_edit_with_editor_1():
     assert m.called
     assert t.called
 
-__id__ = "$Id: test_mattwilson.py 20 2009-08-16 02:39:46Z mw44118 $"
+
+@patch('subprocess.call', m)
+@patch('tempfile.NamedTemporaryFile', t)
+def test_edit_with_editor_2():
+
+    """
+    Verify we can load a variable into the editor.
+    """
+
+    wmw.edit_with_editor('abcdef')
+    assert m.called
+    assert t.called
+
+
+__id__ = "$Id: test_mattwilson.py 21 2009-08-16 02:44:07Z mw44118 $"
